@@ -22,8 +22,8 @@
 *******************************************************************************/
 
 /*  ccd_frame.c: frame operation functions */
-/*  $Revision: 1.23 $ */
-/*  $Date: 2005/11/23 23:22:27 $ */
+/*  $Revision: 1.24 $ */
+/*  $Date: 2007/03/26 13:24:14 $ */
 
 /* Many functions here assume we have float frames - this must be fixed */
 
@@ -549,7 +549,7 @@ static struct ccd_frame *read_fits_file_from_fd(FILE *fp, char *fn, int force_un
 		err_printf("bad NAXIS = %d (!= 2)\n", naxis);
 		goto err_exit;
 	}
-	if (hd->pix_size == 16 || hd->pix_size == -32) {
+	if (hd->pix_size == 16 || hd->pix_size == -32 || hd->pix_size == 32) {
 //		hd->pix_size = 4;
 	} else {
 		err_printf("bad BITPIX = %d (must be 16)\n", hd->pix_size);
@@ -643,6 +643,33 @@ static struct ccd_frame *read_fits_file_from_fd(FILE *fp, char *fn, int force_un
 			}
 		}
 		break;
+	case 32:
+		while(j < all) {
+			k = fread (fv, 1, FITS_HCOLS * FITS_HROWS, fp);
+			if (k != FITS_HCOLS * FITS_HROWS) {
+				err_printf("data is short!\n");
+				break;
+			} else {
+				for(i = 0; i < FITS_HCOLS * FITS_HROWS / 4 && j < all; i++) {
+					unsigned rev;
+					float fds;
+					void *fdp;
+					rev = ntohl(fv[i]);
+					fdp = &rev;
+					fds = *(long *)fdp * 1.0;
+					
+					if (nt && (fds < -65000.0 || fds > 100000.0)) {
+						d4_printf("pixv[%d,%d]=%8g [%08x]\n", 
+							  j % hd->w, j / hd->w, fds, fv[i]);
+						nt --;
+					}
+					
+					*data++ = bs * fds + bz;
+					j++;
+				}
+			}
+		}
+		break;
 	}
 
 //	d3_printf("B");
