@@ -22,8 +22,8 @@
 *******************************************************************************/
 
 // gcx.c: main file for camera control program 
-// $Revision: 1.22 $
-// $Date: 2005/10/10 00:15:18 $
+// $Revision: 1.23 $
+// $Date: 2007/07/04 13:26:50 $
 
 #define _GNU_SOURCE
 
@@ -556,7 +556,7 @@ int main(int ac, char **av)
 
 	GtkWidget *window;
 
-	char *shortopts = "D:p:hP:V:vo:id:b:f:B:M:A:O:usa:T:S:nG:Nj:";
+	char *shortopts = "D:p:hP:V:vo:id:b:f:B:M:A:O:usa:T:S:nG:Nj:F";
 	struct option longopts[] = {
 		{"debug", required_argument, NULL, 'D'},
 		{"dark", required_argument, NULL, 'd'},
